create schema if not exists parking;
use parking;

drop table if exists customer;
CREATE TABLE customer(
	customer_id INT NOT NULL AUTO_INCREMENT,
	first_name VARCHAR(45) NOT NULL,
	last_name VARCHAR(45) NOT NULL,
	email VARCHAR(45) UNIQUE NOT NULL,
	password VARCHAR(45) NOT NULL,
	dob DATE NOT NULL,
	gender ENUM('Male','Female') NOT NULL,
	status ENUM('Active', 'Inactive') NOT NULL,
	
	PRIMARY KEY(customer_id)
);

drop table if exists creditcard;
CREATE TABLE creditcard(
	credit_id INT NOT NULL AUTO_INCREMENT, 
	cc_name VARCHAR(45) NOT NULL, /* name on the credit card */
	name_given VARCHAR(45) NOT NULL, /* name user gives the card */
	credit_number VARCHAR(45) NOT NULL,
	customer_id INT NOT NULL,
	cc_type ENUM('Visa','Mastercard','American Express') NOT NULL,
	
	PRIMARY KEY(credit_id),
	
	FOREIGN KEY(customer_id) REFERENCES customer(customer_id)
	ON UPDATE CASCADE
);

drop table if exists car;
CREATE TABLE car(
	car_id INT NOT NULL AUTO_INCREMENT,
	car_name VARCHAR(45) NOT NULL,
	license_plate VARCHAR(45) NOT NULL,
	us_state varchar(3) NOT NULL,
	customer_id INT NOT NULL,
	
	PRIMARY KEY(car_id),
	FOREIGN KEY(customer_id) REFERENCES customer(customer_id)
	ON UPDATE CASCADE
);

drop table if exists garage;
CREATE TABLE garage(
	garage_id INT NOT NULL,
	name VARCHAR(45) NOT NULL,
	
	PRIMARY KEY(garage_id)
);

drop table if exists parkingspot;
CREATE TABLE parkingspot(
	spot_id INT NOT NULL,
	status ENUM ('VACANT', 'OCCUPIED', 'RESERVED') NOT NULL,
	garage_id INT NOT NULL,
	
	PRIMARY KEY(spot_id, garage_id),
	
	FOREIGN KEY(garage_id) REFERENCES garage(garage_id)
	ON DELETE CASCADE
	ON UPDATE CASCADE
);

drop table if exists reservation;
CREATE TABLE reservation(
	reservation_id INT NOT NULL AUTO_INCREMENT,
	reserve_type ENUM('Confirmed', 'Guaranteed') NOT NULL,
	start_point DATETIME NOT NULL,
	end_point DATETIME NOT NULL,
	customer_id INT NOT NULL,
	credit_id INT, 
	car_id INT NOT NULL,
	garage_id INT NOT NULL,
	spot_id INT NOT NULL, 
	arrive DATETIME,
	depart DATETIME,
	
	PRIMARY KEY(reservation_id),
	
	FOREIGN KEY(customer_id) REFERENCES customer(customer_id)
	ON UPDATE CASCADE,
	
	FOREIGN KEY(credit_id) REFERENCES creditcard(credit_id)
	ON DELETE CASCADE
	ON UPDATE CASCADE,
	
	FOREIGN KEY(spot_id, garage_id) REFERENCES parkingspot(spot_id, garage_id)
	ON UPDATE CASCADE,
	
	FOREIGN KEY(car_id) REFERENCES car(car_id)
	ON DELETE CASCADE
	ON UPDATE CASCADE
);

drop table if exists walkin; 
CREATE TABLE walkin(
	walkin_id INT NOT NULL AUTO_INCREMENT,
	license_plate VARCHAR(45) NOT NULL,
	us_state varchar(3) NOT NULL,
	customer_id INT, 
	spot_id INT NOT NULL,
	garage_id INT NOT NULL,
	entrance DATETIME NOT NULL,
	departure DATETIME,
	
	PRIMARY KEY(walkin_id),
	
	FOREIGN KEY(spot_id, garage_id) REFERENCES parkingspot(spot_id, garage_id)
	ON UPDATE CASCADE,
	
	FOREIGN KEY(customer_id) REFERENCES customer(customer_id)
);

drop table if exists priceplan; 
CREATE TABLE priceplan(
	priceplan_id INT NOT NULL AUTO_INCREMENT,
	garage_id INT NOT NULL,
	registered DECIMAL,
	unregistered DECIMAL,
	
	PRIMARY KEY(priceplan_id),
	
	FOREIGN KEY(garage_id) REFERENCES garage(garage_id)
);

drop table if exists raincheck; 
CREATE TABLE raincheck(
	check_id INT NOT NULL AUTO_INCREMENT,
	duration DECIMAL NOT NULL,
	customer_id INT NOT NULL,
	
	PRIMARY KEY(check_id),
	
	FOREIGN KEY(customer_id) REFERENCES customer(customer_id)
	ON DELETE CASCADE
	ON UPDATE CASCADE
);
