<!--
Written by: Bartosz Agas, Christopher Tran
Tested by: Michael T. Van Genderen, Justin Levatino
Debugged by: Marvin Germar, Tarun Katikaneni
-->

<?php
	include_once('db.php');
	
	$db = new Database;
	$connect = $db->connect();
	
	$plate = $_POST['license_plate'];
	$state = $_POST['us_state'];
	
	$exists = $db->checkIfCarExists($plate, $state);
	
	// car exists
	if($exists>0) {
		$car_id = $db->getCarIdFromPlate($plate, $state);
		
		$checkWalk = $db->checkIfCarIsParkedWalk($plate, $state);
		$checkRes = $db->checkIfCarIsParkedRes($car_id);
		
		// this car is parked in the lot at the moment
		if($checkWalk > 0 || $checkRes > 0) {
			header('Location: ../elevatorCamera.php?park=1');
		}
		
		// this car is not parked in the lot somewhere
		else {
			// current time
			$date = date_create();
			date_timezone_set($date, timezone_open('America/New_York'));
			$current_time = date_format($date, 'Y-m-d H:i:s');
			
			$customer_id = $db->getCustIDfromCarID($car_id);
			
			$next = $db->getUserArriveNull($customer_id);
			
			// succssfully pulled a vehicle and there is an upcoming reservation for it
			if($next>0) {
				$start = $db->getResStart($next);
				$end = $db->getResEnd($next);
				$spot = $db->getSpotFromRes($next);
				$status = $db->getResStatus($next);
				
				$rain_start = new DateTime($start);
				$rain_end = new DateTime($end);
				$rainSec = ($rain_end->format('U') - $rain_start->format('U'));
				$rainHour = $rainSec / 3600;
				
				// check if the customer is early
				// date_diff will be positive if start is after current time
				$interval_start = new DateTime($current_time);
				$interval_end = new DateTime($start);
				$date_diff = ($interval_end->format('U') - $interval_start->format('U')); 
			
				// customer arrives before start time
				if($date_diff > 0) {
					// take off five minutes
					$date_diff = $date_diff - 300;
					
					// customer arrived more than five minutes early
					if($date_diff > 0) {
						header('Location: ../elevatorCamera.php?early=1');
					}
					
					// 5 min prior to start <= customer arrival < start
					else {
						$spot_status = $db->allParkingSpots($spot);
						
						if($spot_status == "VACANT") {
							header('Location: ../elevatorCamera.php?val='.$next.'');
						}
						
						// customer arrived within five min, but spot is still taken
						else {
							header('Location: ../elevatorCamera.php?earAndTake=1');
						}
					}
				}
				
				// customer arrives after start time
				else if($date_diff < 0) {
					// add half an hour
					$date_diff = $date_diff + 1800;
					
					// if date_diff is still negative, customer arrived more than thirty min late
					if($date_diff < 0) {
						// if reservation is 'confirmed', it is now void
						if($status == "Confirmed") {
							header('Location: ../elevatorCamera.php?miss=1');
						}
						
						// if guaranteed, continue and check if spot is avail
						else {
							$spot_status = $db->allParkingSpots($spot);
						
							if($spot_status == "VACANT") {
								header('Location: ../elevatorCamera.php?val='.$next.'');
							}
						
							// check walkins, issue raincheck if none there either
							else {
								$db->deleteReservation($next);
								$temp = 0;
								// check for walk-in availability
								for($i=100 ; $i<200 ; $i=$i+1) {
									$j = $db->allParkingSpots($i);
									
									// if there is a spot, grab the spot id
									if($j == "VACANT"){
										$temp = $j;
										break;
									}
								}
								
								if($temp > 0)
									header('Location: ../elevatorCamera.php?none=1&plate='.$plate.'&state='.$state.'');
								
								else
									header('Location: ../elevatorCamera.php?check='.$rainHour.'&cust='.$customer_id.'');
							}
						}
					}
					
					// customer is within thirty min, proceed
					else {
						$spot_status = $db->allParkingSpots($spot);
						
						if($spot_status == "VACANT") {
							header('Location: ../elevatorCamera.php?val='.$next.'');
						}
						
						else {
							$db->deleteReservation($next);
							$temp = 0;
							// check for walk-in availability
							for($i=100 ; $i<200 ; $i=$i+1) {
								$j = $db->allParkingSpots($i);
									
								// if there is a spot, grab the spot id
								if($j == "VACANT"){
									$temp = $j;
									break;
								}
							}
							
							if($temp > 0)
								header('Location: ../elevatorCamera.php?none=2&plate='.$plate.'&state='.$state.'');
							
							else
								header('Location: ../elevatorCamera.php?check='.$rainHour.'&cust='.$customer_id.'');
						}
					}
				}
				
				// customer arrives exactly on time
				else {
					$spot_status = $db->allParkingSpots($spot);
					
					// spot is not avail
					if($spot_status == "VACANT") {
						header('Location: ../elevatorCamera.php?val='.$next.'');
					}
					
					// check walkins, issue raincheck if none there either
					else {
						 
						$temp = 0;
						// check for walk-in availability
						for($i=100 ; $i<200 ; $i=$i+1) {
							$j = $db->allParkingSpots($i);
									
							// if there is a spot, grab the spot id
							if($j == "VACANT"){
								$temp = $j;
								break;
							}
						}
								
						if($temp > 0)
							header('Location: ../elevatorCamera.php?none=3&plate='.$plate.'&state='.$state.'');
								
						else
							header('Location: ../elevatorCamera.php?check='.$rainHour.'&cust='.$customer_id.'');
					}
				}
			}
			
			else
				// there are no upcoming reservations
				header('Location: ../elevatorCamera.php?none=4&plate='.$plate.'&state='.$state.'');
		}
	}
	
	// not a registered vehicle
	else {
		$checkWalk = $db->checkIfCarIsParkedWalk($plate, $state);
		
		if($checkWalk > 0) {
			// this car is parked in the lot at the moment
			header('Location: ../elevatorCamera.php?park=1');
		}
		
		else
			// car does not exist in db and is not parked in garage
			header('Location: ../elevatorCamera.php?fail=1&plate='.$plate.'&state='.$state.'');
	}
?>