create schema if not exists parking;
use parking;

drop table if exists customer;
CREATE TABLE customer(
	customer_id INT NOT NULL AUTO_INCREMENT,
	first_name VARCHAR(45),
	last_name VARCHAR(45),
	email VARCHAR(45) UNIQUE,
	password VARCHAR(45),
	dob DATE,
	gender ENUM('Male','Female'),
	
	PRIMARY KEY(customer_id)
);

drop table if exists creditcard;
CREATE TABLE creditcard(
	credit_number VARCHAR(45),
	customer_id INT,
	cc_name VARCHAR(45),
	cc_type ENUM('Visa','Mastercard','American Express'),
	
	PRIMARY KEY(customer_id, credit_number),
	
	FOREIGN KEY(customer_id) REFERENCES customer(customer_id)
);

drop table if exists car;
CREATE TABLE car(
	car_id INT NOT NULL AUTO_INCREMENT,
	license_plate VARCHAR(45) NOT NULL,
	us_state varchar(3) NOT NULL,
	customer_id INT NOT NULL,
	
	PRIMARY KEY(car_id),
	FOREIGN KEY(customer_id) REFERENCES customer(customer_id)
);

drop table if exists garage;
CREATE TABLE garage(
	garage_id INT NOT NULL,
	name VARCHAR(45) NOT NULL,
	
	PRIMARY KEY(garage_id)
);

drop table if exists parkingspot;
CREATE TABLE parkingspot(
	spot_id INT NOT NULL,
	status ENUM ('VACANT', 'OCCUPIED', 'RESERVED'),
	garage_id INT NOT NULL,
	
	PRIMARY KEY(spot_id, garage_id),
	
	FOREIGN KEY(garage_id) REFERENCES garage(garage_id)
);

drop table if exists reservation;
CREATE TABLE reservation(
	reservation_id INT NOT NULL AUTO_INCREMENT,
	reserve_type ENUM('Confirmed', 'Guaranteed'),
	start_point DATETIME,
	end_point DATETIME,
	customer_id INT NOT NULL,
	car_id INT,
	garage_id INT,
	spot_id INT,
	
	PRIMARY KEY(reservation_id),
	
	FOREIGN KEY(customer_id) REFERENCES customer(customer_id),
	
	FOREIGN KEY(spot_id) REFERENCES parkingspot(spot_id),
	
	FOREIGN KEY(car_id) REFERENCES car(car_id),
	
	FOREIGN KEY(garage_id) REFERENCES garage(garage_id)
);

drop table if exists walkin;
CREATE TABLE walkin(
	walkin_id INT NOT NULL AUTO_INCREMENT,
	billing_name VARCHAR(45),
	billing_credit_number VARCHAR(45),
	billing_cc_type ENUM('Visa','Mastercard','American Express'),
	
	PRIMARY KEY(walkin_id)
);